@@ -1,5 +1,5 @@
 //  gnoMint: a graphical interface for managing a certification authority
-//  Copyright (C) 2006,2007,2008 David Marín Carreño <davefx@gmail.com>
+//  Copyright (C) 2006-2009 David Marín Carreño <davefx@gmail.com>
 //
 //  This file is part of gnoMint.
 //
@@ -30,7 +30,7 @@ void tls_init ()
 
 }
 
-gchar * tls_generate_rsa_keys (CaCreationData *creation_data,
+gchar * tls_generate_rsa_keys (TlsCreationData *creation_data,
 			       gchar ** private_key,
 			       gnutls_x509_privkey_t **key)
 {
@@ -64,7 +64,7 @@ gchar * tls_generate_rsa_keys (CaCreationData *creation_data,
 	return NULL;
 }
 
-gchar * tls_generate_dsa_keys (CaCreationData *creation_data,
+gchar * tls_generate_dsa_keys (TlsCreationData *creation_data,
 			       gchar ** private_key,
 			       gnutls_x509_privkey_t **key)
 {
@@ -416,7 +416,7 @@ gnutls_datum_t * tls_generate_pkcs12 (gchar *pem_cert, gchar *pem_private_key, g
 }
 
 
-gchar * tls_generate_self_signed_certificate (CaCreationData * creation_data, 
+gchar * tls_generate_self_signed_certificate (TlsCreationData * creation_data, 
 					      gnutls_x509_privkey_t *key,
 					      gchar ** certificate)
 {
@@ -560,7 +560,7 @@ gchar * tls_generate_self_signed_certificate (CaCreationData * creation_data,
 }
 
 
-gchar * tls_generate_csr (CaCreationData * creation_data, 
+gchar * tls_generate_csr (TlsCreationData * creation_data, 
 			  gnutls_x509_privkey_t *key,
 			  gchar ** csr)
 {
@@ -625,7 +625,7 @@ gchar * tls_generate_csr (CaCreationData * creation_data,
 
 }
 
-gchar * tls_generate_certificate (CertCreationData * creation_data,
+gchar * tls_generate_certificate (TlsCertCreationData * creation_data,
 				  gchar *csr_pem,
 				  gchar *ca_cert_pem,
 				  gchar *ca_priv_key_pem,
@@ -1190,7 +1190,10 @@ TlsCsr * tls_parse_csr_pem (const char * pem_csr)
 	gnutls_datum_t pem_datum;
 	gnutls_x509_crq_t * csr = g_new0 (gnutls_x509_crq_t, 1);
 	gchar *aux = NULL;
-	
+#ifdef ADVANCED_GNUTLS
+	guchar *uaux = NULL;
+#endif
+
 	size_t size;
 
 	TlsCsr *res = g_new0 (TlsCsr, 1);
@@ -1273,13 +1276,13 @@ TlsCsr * tls_parse_csr_pem (const char * pem_csr)
 
 #ifdef ADVANCED_GNUTLS
 	size = 0;
-	gnutls_x509_crq_get_key_id (*csr, aux, &size);
+	gnutls_x509_crq_get_key_id (*csr, 0, uaux, &size);
 	if (size) {
 		aux = g_new0(gchar, size);
-		gnutls_x509_crq_get_key_id (*csr, aux, &size);
+		gnutls_x509_crq_get_key_id (*csr, 0, uaux, &size);
 		res->key_id = g_strdup (aux);
 		g_free (aux);
-		aux = NULL;
+		uaux = NULL;
 	}
 #endif
 
@@ -1595,6 +1598,30 @@ gchar * tls_get_public_key_id (const gchar *certificate_pem)
 
 }
 
+void tls_creation_data_free (TlsCreationData *cd)
+{
+	if (cd->country)
+		g_free (cd->country);
+	if (cd->state)
+		g_free (cd->state);
+	if (cd->city)
+		g_free (cd->city);
+	if (cd->org)
+		g_free (cd->org);
+	if (cd->ou)
+		g_free (cd->ou);
+	if (cd->cn)
+		g_free (cd->cn);
+	if (cd->emailAddress)
+		g_free (cd->emailAddress);
+	if (cd->password)
+		g_free (cd->password);
+        if (cd->parent_ca_id_str)
+                g_free (cd->parent_ca_id_str);
+	g_free (cd);
+}
+
+
 #ifdef ADVANCED_GNUTLS
 
 gchar * tls_get_csr_public_key_id (const gchar *csr_pem)
@@ -1642,4 +1669,6 @@ gchar * tls_get_csr_public_key_id (const gchar *csr_pem)
 
 }
 
+
+
 #endif
